@@ -5,6 +5,7 @@
  */
 
 #include "config.h"
+#include "libsync/creds/abstractcredentials.h"
 #include "owncloudpropagator_p.h"
 #include "propagatedownload.h"
 #include "networkjobs.h"
@@ -116,12 +117,13 @@ void GETFileJob::start()
     }
 
     req.setPriority(QNetworkRequest::LowPriority); // Long downloads must not block non-propagation jobs.
-    req.setDecompressedSafetyCheckThreshold(CustomDecompressedSafetyCheckThreshold);
+    req.setDecompressedSafetyCheckThreshold(_decompressionThresholdBase + CustomDecompressedSafetyCheckThreshold);
 
     if (_directDownloadUrl.isEmpty()) {
         sendRequest("GET", makeDavUrl(path()), req);
     } else {
         // Use direct URL
+        req.setAttribute(AbstractCredentials::DontAddCredentialsAttribute, true);
         sendRequest("GET", _directDownloadUrl, req);
     }
 
@@ -737,6 +739,9 @@ void PropagateDownloadFile::startDownload()
             url,
             &_tmpFile, headers, expectedEtagForResume, _resumeStart, this);
     }
+    if (_item->_size >= 0) {
+        _job->setDecompressionThresholdBase(_item->_size);
+    }
     _job->setBandwidthManager(&propagator()->_bandwidthManager);
     connect(_job.data(), &GETFileJob::finishedSignal, this, &PropagateDownloadFile::slotGetFinished);
     connect(_job.data(), &GETFileJob::downloadProgress, this, &PropagateDownloadFile::slotDownloadProgress);
